module Bindep
  module Helpers
    # Run a command, supply stdin and capture stdout and stderr.
    def self.cmd(command, stdin = nil, raise_on_error = true)
      stdout, stderr, status = Open3.capture3 command, stdin_data: stdin, binmode: true

      if raise_on_error && (status.exitstatus != 0 || stderr =~ /error/i)
        raise RuntimeError, "Command '#{command}' returned status #{status.exitstatus}"
      end

      [ stdout, stderr, status.exitstatus ]
    end

    # Run a command interactively, return exit status
    def self.cmd_interactive(command, raise_on_error = true)
      system command

      if raise_on_error && !$?.exitstatus.zero?
        raise RuntimeError, "Command '#{command}' returned status #{$?.exitstatus}"
      end

      $?.exitstatus
    end

    # Check if a shell command exists (using "which").
    def self.command_exists?(cmd)
      _, _, status = Helpers.cmd "which #{cmd.strip}", nil, false
      status.zero?
    end

    # Check if "which" command is available and works correctly.
    def self.which_test
      command_exists?("which") && !command_exists?("foo_bar_command_does_not_exist")
    end
  end
end
