module Bindep
  class Item
    attr_reader :id
    attr_accessor :command, :apt, :yum, :brew, :npm, :rubygem, :install_command, :depends

    def initialize(id)
      @id = id.to_sym
    end

    # Get the command for the current system. Return nil if command is not available.
    def local_command(reset = false)
      @local_command = nil if reset

      @local_command ||= [ command ].flatten.compact.find do |cmd|
        Helpers.command_exists? cmd
      end
    end

    # Get the installation commands for the current system as a single string.
    # Return nil if there is no command that fits the current system.
    def install_command
      list = []

      list << OS.apt_install(apt) if apt && OS.apt? && !OS.yum?
      list << OS.yum_install(yum) if yum && OS.yum? && !OS.apt?
      list << OS.brew_install(brew) if brew && OS.brew?
      list << OS.npm_install(npm) if npm && OS.npm?
      list << OS.rubygem_install(rubygem) if rubygem && OS.rubygem?
      list << @install_command if @install_command

      list.empty? ? nil : list.join("; ")
    end
  end
end
